#!/bin/bash

__system_reload() {
    rm -f /var/lock/kolibri-update-channels.service.stamp
    systemctl daemon-reload
    systemctl restart NetworkManager-dispatcher.service
}

__run_install() {
    set -o xtrace

    install -D kolibri-update-channels -t /usr/local/bin/
    install -D kolibri-update-channels.service -t /usr/local/lib/systemd/system/
    install -D kolibri-update-channels.timer -t /usr/local/lib/systemd/system/
    echo "KOLIBRI_UPDATE_CHANNELS_BASEURL=$arg_base_url" > environment-file
    install -D environment-file -t /usr/local/etc/kolibri-update-channels/

    __system_reload

    systemctl enable kolibri-update-channels.timer
    systemctl start kolibri-update-channels.timer

    set +o xtrace
}

__run_uninstall() {
    set -o xtrace

    systemctl stop kolibri-update-channels.timer
    systemctl disable kolibri-update-channels.timer

    rm -f /etc/NetworkManager/dispatcher.d/50-kolibri-update-channels
    rm -f /usr/local/bin/kolibri-update-channels
    rm -f /usr/local/lib/systemd/system/kolibri-update-channels.service
    rm -f /usr/local/lib/systemd/system/kolibri-update-channels.timer
    rm -fr /usr/local/etc/kolibri-update-channels

    __system_reload

    set +o xtrace
}

if [ $(id -u) != "0" ]; then
    echo "$0: Program requires superuser privileges" >&2
    exit 1
fi

args=$(getopt -o h -l "baseurl:,action:" -- "$@")

[ $? -eq 0 ] || {
    echo "$0: Incorrect options provided" >&2
    exit 1
}

arg_base_url=""
arg_action=""

eval set -- "$args"

while true; do
    case "$1" in
    --baseurl)
        shift;
        arg_base_url=$1
        ;;
    --action)
        shift;
        arg_action=$1
        ;;
    --)
        shift
        break
        ;;
    esac
    shift
done

if [ "$arg_action" = "install" ]; then
    __run_uninstall
    __run_install
elif [ "$arg_action" = "uninstall" ]; then
    __run_uninstall
else
    echo "$0: Action is not valid, it must be 'install' or 'uninstall'" >&2
    exit 1
fi
